@@ -27,7 +27,7 @@ hashing
 .. automodule:: revscoring.datasources.meta.hashing
 
 indexable
-+++++++
++++++++++
 .. automodule:: revscoring.datasources.meta.indexable
 
 mappers
@@ -37,4 +37,8 @@ mappers
 selectors
 +++++++++
 .. automodule:: revscoring.datasources.meta.selectors
+
+timestamp
++++++++++
+.. automodule:: revscoring.datasources.meta.timestamp
 """
