@@ -1,13 +1,11 @@
-from revscoring.dependencies import DependentSet
-
 from . import edit, parsed, sentences, tokenized
 
 
-class BaseRevision(DependentSet):
-
+class Revision(parsed.Revision, sentences.Revision, tokenized.Revision):
+    # pass
     def __init__(self, name, revision_datasources):
-        super().__init__(name)
-        self.text = revision_datasources.text
+        # Initializes all of the Revision datasources
+        super().__init__(name, revision_datasources)
 
         if hasattr(revision_datasources, "parent"):
             self.parent = Revision(
@@ -15,25 +13,10 @@ class BaseRevision(DependentSet):
                 revision_datasources.parent
             )
 
-
-class Revision(parsed.Revision, sentences.Revision, tokenized.Revision,
-               BaseRevision):
-
-    def __init__(self, name, revision_datasources):
-        # Initializes all of the Revision datasources
-        super().__init__(name, revision_datasources)
-
         # Initializes the diff using the Revision datasources
         if hasattr(revision_datasources, "diff"):
             self.diff = Diff(name + ".diff", self)
 
 
-class BaseDiff(DependentSet):
-
-    def __init__(self, name, revision):
-        super().__init__(name)
-        self.revision = revision
-
-
-class Diff(edit.Diff, sentences.Diff, tokenized.Diff, BaseDiff):
+class Diff(edit.Diff, sentences.Diff, tokenized.Diff):
     pass
