@@ -35,20 +35,6 @@ def test_content():
     assert (pickle.loads(pickle.dumps(revision.content_chars)) ==
             revision.content_chars)
 
-    test_data = """
-        Playing games has always been thought to be
-        important to the development of well-balanced and creative children;
-        however, what part, if any, they should play in the lives of adults
-        has never been researched that deeply. I believe that playing games
-        is every bit as important for adults as for children. Not only is
-        taking time out to play games with our children and other adults
-        valuable to building interpersonal relationships but is also a
-        wonderful way to release built up tension."""
-    cache = {r_text: test_data}
-    assert solve(revision.flesh_kincaid, cache=cache) == 52.23
-    assert (pickle.loads(pickle.dumps(revision.flesh_kincaid)) ==
-            revision.flesh_kincaid)
-
 
 def test_headings():
 
