@@ -3,7 +3,7 @@ from collections import OrderedDict
 from revscoring.scoring.statistics.classification.micro_macro_stats import \
     MicroMacroStats
 from revscoring.scoring.statistics.classification.scaled_prediction_statistics import \
-    ScaledPredictionStatistics as SPS
+    ScaledPredictionStatistics as SPS # noqa
 
 
 def test_micro_macro_stats():
